@@ -82,11 +82,13 @@ class TestRunner(unittest.TestCase):
             'docker', 'run',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR)),
             '-v', get_volume_mapping('%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR)),
@@ -126,11 +128,13 @@ class TestRunner(unittest.TestCase):
             'docker', 'run',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR)),
             '-v', get_volume_mapping('%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR)),
@@ -169,6 +173,7 @@ class TestRunner(unittest.TestCase):
             'docker', 'run',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'KEY1=VAL1',
@@ -176,6 +181,7 @@ class TestRunner(unittest.TestCase):
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR)),
             '-v', get_volume_mapping('%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR)),
@@ -222,12 +228,14 @@ class TestRunner(unittest.TestCase):
             'docker', 'run',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '--env-file', ENV_FILE_PATH,
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(
                 homedir=HOME_DIR)),
@@ -277,6 +285,7 @@ class TestRunner(unittest.TestCase):
             'docker', 'run',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', 'host',
             '--env-file', ENV_FILE_PATH,
@@ -284,6 +293,7 @@ class TestRunner(unittest.TestCase):
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(
                 homedir=HOME_DIR),
@@ -330,11 +340,13 @@ class TestRunner(unittest.TestCase):
             '-e', 'SKIPPER_INTERACTIVE=True',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR)),
             '-v', get_volume_mapping('%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR)),
@@ -373,11 +385,13 @@ class TestRunner(unittest.TestCase):
             'docker', 'run',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR)),
             '-v', get_volume_mapping('%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR)),
@@ -418,6 +432,7 @@ class TestRunner(unittest.TestCase):
             'test',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'KEY1=VAL1',
@@ -425,6 +440,7 @@ class TestRunner(unittest.TestCase):
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', get_volume_mapping('%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR)),
             '-v', get_volume_mapping('%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR)),
@@ -471,6 +487,7 @@ class TestRunner(unittest.TestCase):
             'test',
             '-t',
             '-e', 'KEEP_CONTAINERS=True',
+            '--ulimit', 'nofile=65536:65536',
             '--privileged',
             '--net', get_default_net(),
             '-e', 'KEY1=VAL1',
@@ -478,6 +495,7 @@ class TestRunner(unittest.TestCase):
             '-e', 'SKIPPER_USERNAME=testuser',
             '-e', 'SKIPPER_UID=%(user_uid)s' % dict(user_uid=USER_ID),
             '-e', 'HOME=%(homedir)s' % dict(homedir=HOME_DIR),
+            '-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command()),
             '-e', 'SKIPPER_DOCKER_GID=978',
             '-v', '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=HOME_DIR),
             '-v', '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=HOME_DIR),
